@@ -1,7 +1,7 @@
 """forge specific entities class for imported entities
 
 :organization: Logilab
-:copyright: 2006-2009 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+:copyright: 2006-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 __docformat__ = "restructuredtext en"
@@ -11,13 +11,14 @@ from datetime import datetime, date, timedelta
 from logilab.common.date import nb_open_days
 
 from cubicweb.entities import AnyEntity, fetch_config
+from cubicweb.entities.adapters import IFTIndexableAdapter
 from cubicweb.interfaces import IPrevNext, ICalendarViews
+from cubicweb.selectors import is_instance
 
 from cubes.card.entities import Card as BaseCard
-from cubes.file.entities import File as BaseFile, Image as BaseImage
+from cubes.file.entities import File as BaseFile
 from cubes.comment.entities import Comment as BaseComment
 from cubes.email.entities import Email as BaseEmail
-from cubes.nosylist.interfaces import INosyList
 from cubes.tracker.entities import project, version, ticket
 from cubes.tracker.entities import ProjectItemMixIn, fixed_orderby_rql
 
@@ -37,7 +38,6 @@ class ExtProject(AnyEntity):
 
 class Project(project.Project):
 
-    __implements__ = project.Project.__implements__ + (INosyList,)
     __permissions__ = ('developer', 'client')
     fetch_attrs = project.Project.fetch_attrs + ('homepage', 'summary')
 
@@ -48,17 +48,20 @@ class Project(project.Project):
     sort_defs = (('in_state', 'S'), ('num', 'VN'), ('type', 'TT'),
                  ('priority', 'PR'))
     def tickets_rql(self, limit=None):
-        rql = ('Any B,TT,NOW - CD, NOW - BMD, U,PR,S,C,V,group_concat(TN),BDF,BD,BC,VN,P,BT,CD,BMD,UL '
-               'GROUPBY B,TT,CD,PR,S,C,V,U,VN,BDF,BD,BC,P,BT,BMD,UL %s WHERE '
-               'B type TT, B priority PR, B in_state S, B creation_date CD, '
-               'B description_format BDF, B description BD, B load_left BC, '
-               'B title BT, B modification_date BMD, '
-               'B load C, T? tags B, T name TN, B done_in V?, V num VN, '
-               'B created_by U?, U login UL, B concerns P, P eid %s'
-               ) % (fixed_orderby_rql(self.sort_defs), self.eid)
-        if limit:
-            rql += ' LIMIT ' + `limit`
-        return rql
+        return ('Any B,TT,NOW - CD, NOW - BMD, U,PR,S,C,V,group_concat(TN),BDF,BD,BC,VN,P,BT,CD,BMD,UL '
+                'GROUPBY B,TT,CD,PR,S,C,V,U,VN,BDF,BD,BC,P,BT,BMD,UL %s %s WHERE '
+                'B type TT, B priority PR, B in_state S, B creation_date CD, '
+                'B description_format BDF, B description BD, B load_left BC, '
+                'B title BT, B modification_date BMD, '
+                'B load C, T? tags B, T name TN, B done_in V?, V num VN, '
+                'B created_by U?, U login UL, B concerns P, P eid %s'
+                ) % (fixed_orderby_rql(self.sort_defs),
+                     limit and ' LIMIT %s' % limit or '',
+                     self.eid)
+
+class ProjectIFTIndexableAdapter(IFTIndexableAdapter):
+    __select__ = is_instance('Project')
+    entity_weight = 20.0
 
 
 # version ######################################################################
@@ -86,14 +89,6 @@ class Version(version.Version):
     def tarball_name(self):
         return '%s-%s.tar.gz' % (self.project.name, self.num)
 
-    def download_url(self):
-        downloadurl = self.project.downloadurl
-        if not downloadurl:
-            return
-        if not downloadurl[-1] == '/':
-            downloadurl +=  '/'
-        return '%s%s' % (downloadurl, self.tarball_name())
-
     def estimated_load(self):
         """return the actually estimated load of the version:
         even if some tasks are marked as done, consider their estimated load and
@@ -113,6 +108,18 @@ class Version(version.Version):
                 total += estimated_load
         return (total, missing)
 
+    def update_progress(self):
+        progress_target = 0
+        progress_todo = 0
+        progress_done = 0
+        for ticket in self.reverse_done_in:
+            progress_target += ticket.corrected_load()
+            progress_todo += ticket.corrected_load_left()
+        progress_done = max(0, progress_target - progress_todo)
+        self.set_attributes(progress_target=progress_target,
+                            progress_todo=progress_todo,
+                            progress_done=progress_done)
+
     # ui utilities ############################################################
 
     # number of columns to display
@@ -138,36 +145,25 @@ class Version(version.Version):
                 'B title BT, B description BD, B description_format BDF'
                 % self.eid)
 
-    def progress_class(self):
-        """return a class name according to % progress of a version"""
-        progress = self.progress()
-        if progress == 100:
-            return 'complete'
-        elif progress == 0:
-            return 'none'
-        elif progress > 50:
-            return 'over50'
-        return 'below50'
 
-    # IMileStone interface ####################################################
-
-    parent_type = 'Project'
+class VersionIMileStoneAdapter(version.VersionIMileStoneAdapter):
 
     def progress_info(self):
         """returns a dictionary describing load and progress of the version"""
-        pinfo = {'estimated': self.progress_target,
-                 'done': self.progress_done,
-                 'todo': self.progress_todo,
-                 'notestimated': len([entity for entity in self.reverse_done_in
-                                      if entity.load is None]),
-                 }
-        return pinfo
+        version = self.entity
+        return {'estimated': version.progress_target,
+                'done': version.progress_done,
+                'todo': version.progress_todo,
+                'notestimated': len([ticket for ticket in version.reverse_done_in
+                                     if ticket.load is None]),
+                }
 
     def eta_date(self):
         """return expected date based on remaining tasks and velocity"""
-        if self.state != 'dev':
+        version = self.entity
+        if version.cw_adapt_to('IWorkflowable').state != 'dev':
             return None
-        velocity = self.velocity()
+        velocity = version.velocity()
         if velocity is None:
             return None
         # XXX if velocity == 0, use a hidden attribute which is computed from
@@ -175,29 +171,14 @@ class Version(version.Version):
         velocity = velocity or 1
         return datetime.now() + timedelta(self.todo / velocity)
 
-    def contractors(self):
-        return self.todo_by
-
-    def update_progress(self):
-        if not 'progress_target' in self.e_schema.subject_relations():
-            return # XXX necessary for 1.1.0 migration
-        self.progress_target = 0
-        self.progress_todo = 0
-        self.progress_done = 0
-        for ticket in self.reverse_done_in:
-            self.progress_target += ticket.corrected_load()
-            self.progress_todo += ticket.corrected_load_left()
-        self.progress_done = max(0, self.progress_target - self.progress_todo)
-        self.set_attributes(progress_target=self.progress_target,
-                            progress_todo=self.progress_todo,
-                            progress_done=self.progress_done, _cw_unsafe=True)
-
+# qui peut le plus peut le moins
+class VersionIProgressAdapter(VersionIMileStoneAdapter):
+    __regid__ = 'IProgress'
 
 # ticket #######################################################################
 
 class Ticket(ticket.Ticket):
 
-    __implements__ = ticket.Ticket.__implements__ + (INosyList,)
     fetch_attrs = ('title', 'type', 'priority', 'load', 'load_left', 'in_state')
     noload_cost = 10
 
@@ -215,6 +196,10 @@ class Ticket(ticket.Ticket):
             return self.load_left
         return self.corrected_load()
 
+class TicketIFTIndexableAdapter(IFTIndexableAdapter):
+    __select__ = is_instance('Ticket')
+    entity_weight = 10.0
+
 
 # forge specific entities and library overrides ################################
 
@@ -237,28 +222,16 @@ class Card(ProjectItemMixIn, BaseCard):
         if self.test_case_for:
             return self.test_case_for[0].project
 
-    def breadcrumbs(self, view=None, recurs=False):
-        if self.project:
-            path = self.project.breadcrumbs(view, True)
-            if self.reverse_documented_by:
-                url = '%s/%s' % (self.project.absolute_url(), 'documentation')
-                path.append( (url, self._cw._('documentation')) )
-            elif self.test_case_for:
-                path = self.test_case_for[0].breadcrumbs(view, True)
-            else:
-                url = '%s/%s' % (self.project.absolute_url(), 'testcases')
-                path.append( (url, self._cw._('test cases')) )
-            path.append(self)
-            return path
-        return super(Card, self).breadcrumbs(view, recurs)
-
 
 class Comment(BaseComment):
 
     @property
     def project(self):
         """project item interface"""
-        return self.root().project
+        try:
+            return self.cw_adapt_to('ITree').root().project
+        except AttributeError:
+            return None
 
 
 class File(ProjectItemMixIn, BaseFile):
@@ -270,38 +243,19 @@ class File(ProjectItemMixIn, BaseFile):
             return self.reverse_documented_by[0]
         if self.reverse_attachment:
             return self.reverse_attachment[0].project
-
-    def breadcrumbs(self, view=None, recurs=False):
-        if self.reverse_attachment:
-            if self.reverse_attachment[0].e_schema != 'Email':
-                path = self.reverse_attachment[0].breadcrumbs(view, True)
-                path.append(self.reverse_attachment[0])
-                return path
-        if self.project:
-            path = [self.project]
-            if self.reverse_documented_by:
-                url = '%s/%s' % (self.project.absolute_url(), 'documentation')
-                label = self._cw._('documentation')
-                path.append( (url, label) )
-            return path
-        return super(File, self).breadcrumbs(view, recurs)
-
-
-class Image(ProjectItemMixIn, BaseImage):
-
-    @property
-    def project(self):
-        """project item interface"""
-        # check reverse_screenshot first, we may be attached to an email
         if self.reverse_screenshot:
             return self.reverse_screenshot[0].project
-        if self.reverse_attachment:
-            return self.reverse_attachment[0].project
-
-    def parent(self):
-        return self.project
-
 
 
+# XXX necessary?
 class Email(ProjectItemMixIn, BaseEmail):
     pass
+
+
+def registration_callback(vreg):
+    vreg.register_all(globals().values(), __name__,
+                      (VersionIMileStoneAdapter, VersionIProgressAdapter))
+    vreg.register_and_replace(VersionIMileStoneAdapter,
+                              version.VersionIMileStoneAdapter)
+    vreg.register_and_replace(VersionIProgressAdapter,
+                              version.VersionIProgressAdapter)
