@@ -17,7 +17,7 @@ Local permission (granted by project):
   * add documentation file, screenshots, ticket's attachment
 
 :organization: Logilab
-:copyright: 2003-2009 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+:copyright: 2003-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 __docformat__ = "restructuredtext en"
@@ -34,14 +34,13 @@ from cubes.tracker.schemaperms import (
 
 try:
     from cubes.tracker.schema import Project, Ticket, Version
-    from cubes.file.schema import File, Image
+    from cubes.file.schema import File
     from cubes.card.schema import Card
 except (ImportError, NameError):
     Project = import_erschema('Project')
     Ticket = import_erschema('Ticket')
     Version = import_erschema('Version')
     File = import_erschema('File')
-    Image = import_erschema('Image')
     Card = import_erschema('Card')
 
 Project.add_relation(String(maxsize=128,
@@ -94,7 +93,7 @@ class screenshot(RelationDefinition):
         'delete': ('managers', 'staff', sexpr('developer', 'client'),),
     }
     subject = 'Project'
-    object = 'Image'
+    object = 'File'
     constraints = [RQLVocabularyConstraint('S in_state ST, ST name "active development"')]
     description = _('project\'s screenshot')
 
@@ -151,7 +150,7 @@ class attachment(RelationDefinition):
         'delete': ('managers', 'staff', RRQLExpression('U has_update_permission S', 'S')),
     }
     subject = 'Ticket'
-    object = ('File', 'Image')
+    object = 'File'
     description = _('files related to this ticket (screenshot, file needed to '
                     'reproduce a bug...)')
 
@@ -197,21 +196,12 @@ File.__permissions__ = {
     'add':    ('managers', 'staff',
                ERQLExpression('Y attachment X, Y is Email, U has_update_permission Y'),
                xorexpr('attachment', 'File', 'developer', 'client'),
+               xorexpr('screenshot', 'File', 'developer', 'client'),
                xorexpr('documented_by', 'File', 'developer', 'client'),),
     'update': ('managers', 'staff', 'owners',),
     'delete': ('managers', 'owners'),
     }
 
-
-Image.__permissions__ = {
-    'read':   ('managers', 'users', 'guests'),
-    'add':    ('managers', 'staff',
-               xorexpr('attachment', 'Image', 'developer', 'client'),
-               xorexpr('screenshot', 'Image', 'developer', 'client'),),
-    'update': ('managers', 'staff', 'owners',),
-    'delete': ('managers', 'owners'),
-    }
-
 # XXX should be independant of testcard cube'schema
 Card.__permissions__ = {
     'read':   ('managers', 'users', 'guests'),
@@ -232,21 +222,19 @@ class interested_in(RelationDefinition):
 
 class nosy_list(RelationDefinition):
     subject = ('Email', 'ExtProject', 'Project', 'Version', 'Ticket',
-               'Comment', 'Image', 'File', 'Card', 'TestInstance')
+               'Comment', 'File', 'Card', 'TestInstance')
     object = 'CWUser'
 
 # extra relation definitions ##################################################
 
 class see_also(RelationDefinition):
     symmetric = True
-    subject = ('ExtProject', 'Project', 'Ticket', 'Card', 'File', 'Image',
-               'Email')
-    object = ('ExtProject', 'Project', 'Ticket', 'Card', 'File', 'Image',
-              'Email')
+    subject = ('ExtProject', 'Project', 'Ticket', 'Card', 'File', 'Email')
+    object = ('ExtProject', 'Project', 'Ticket', 'Card', 'File', 'Email')
 
 class comments(RelationDefinition):
     subject = 'Comment'
-    object = ('Ticket', 'Card', 'File', 'Image', 'Email')
+    object = ('Ticket', 'Card', 'File', 'Email')
     cardinality = '1*'
     composite = 'object'
 
@@ -255,12 +243,12 @@ class tags(RelationDefinition):
     subject = 'Tag'
     object = ('ExtProject', 'Project', 'Version', 'Ticket',
               'License', 'MailingList',
-              'Card', 'File', 'Image', 'Email')
+              'Card', 'File', 'Email')
 
 class filed_under(RelationDefinition):
     subject = ('ExtProject', 'Project', 'Card', 'File')
     object = 'Folder'
 
 class require_permission(RelationDefinition):
-    subject = ('ExtProject', 'Comment', 'Image', 'File', 'Card', 'TestInstance')
+    subject = ('ExtProject', 'Comment', 'File', 'Card', 'TestInstance')
     object = 'CWPermission'
