@@ -5,7 +5,7 @@ repo2, cnx2, repo3, cnx3, eids = ms_test_init()
 
 class ThreeSourcesTC(BaseMSTC):
     def test_projects_interested_in(self):
-        rset = self.execute('Any P,N WHERE P name N, X interested_in P, X eid %(x)s', {'x': self.session.user.eid}, 'x')
+        rset = self.execute('Any P,N WHERE P name N, X interested_in P, X eid %(x)s', {'x': self.session.user.eid})
         self.assertEquals(len(rset), 3)
 
     def test_nonregr2(self):
@@ -15,8 +15,8 @@ class ThreeSourcesTC(BaseMSTC):
         # test we can a change a ticket state (and implicitly its version'state by commiting
         self.fire_transition(self.ip1t1eid, 'start')
         self.commit()
-        ip1v1 = self.execute('Any X WHERE X eid %(x)s', {'x': self.ip1v1eid}, 'x').get_entity(0, 0)
-        self.assertEquals(ip1v1.state, 'dev')
+        ip1v1 = self.execute('Any X WHERE X eid %(x)s', {'x': self.ip1v1eid}).get_entity(0, 0)
+        self.assertEquals(ip1v1.cw_adapt_to('IWorkflowable').state, 'dev')
 
     def test_nonregr6(self):
         # XXX monkey patch of sqlgenerator needed since sqlite needs distinct
