@@ -35,7 +35,7 @@ class NotificationTC(TrackerBaseTC):
         # check that other notification when project isn't being created are
         # using regulary nosy list recipients
         MAILBOX[:] = ()
-        p.fire_transition('temporarily stop development')
+        p.cw_adapt_to('IWorkflowable').fire_transition('temporarily stop development')
         self.commit()
         self.assertEquals([re.sub('#\d+', '#EID', e.subject) for e in MAILBOX],
                           ['[hop] project is now in state "asleep"',
@@ -57,3 +57,6 @@ class NotificationTC(TrackerBaseTC):
         self.assertEquals(MAILBOX[1].recipients, ['logilabien@logilab.org'])
 
 
+if __name__ == '__main__':
+    from logilab.common.testlib import unittest_main
+    unittest_main()
