@@ -9,7 +9,7 @@ _ = unicode
 
 from logilab.mtconverter import xml_escape
 
-from cubicweb.selectors import one_line_rset, score_entity, implements
+from cubicweb.selectors import one_line_rset, score_entity, is_instance
 from cubicweb.view import EntityView
 from cubicweb import tags, uilib
 from cubicweb.web import uicfg, action, component
@@ -26,7 +26,7 @@ tracker.ProjectStatsView.default_rql = (
 # primary view and tabs ########################################################
 
 class ExtProjectPrimaryView(primary.PrimaryView):
-    __select__ = implements('ExtProject')
+    __select__ = is_instance('ExtProject')
     show_attr_label = False
 
     def render_entity_title(self, entity):
@@ -57,7 +57,7 @@ for attr in ('homepage', 'vcsurl', 'reporturl', 'downloadurl'):
 class ProjectDocumentationView(tabs.EntityRelationView):
     """display project's documentation"""
     __regid__ = title = _('projectdocumentation')
-    __select__ = tabs.EntityRelationView.__select__ & implements('Project')
+    __select__ = tabs.EntityRelationView.__select__ & is_instance('Project')
     rtype = 'documented_by'
     target = 'object'
 
@@ -70,19 +70,19 @@ class ProjectDocumentationTab(ProjectDocumentationView):
 class ProjectScreenshotsView(tabs.EntityRelationView):
     """display project's screenshots"""
     __regid__ = title = _('projectscreenshots')
-    __select__ = tabs.EntityRelationView.__select__ & implements('Project')
+    __select__ = tabs.EntityRelationView.__select__ & is_instance('Project')
     rtype = 'screenshot'
     target = 'object'
     vid = 'gallery'
 
 class ProjectScreenshotsTab(ProjectScreenshotsView):
     __regid__ = 'screenshots_tab'
-    __select__ = tabs.EntityRelationView.__select__ & implements('Project')
+    __select__ = tabs.EntityRelationView.__select__ & is_instance('Project')
     title = None # should not appears in possible views
 
 class ProjectBrowseTab(EntityView):
     __regid__ = 'codebrowser_tab'
-    __select__ = implements('Project') & score_entity(lambda x: x.vcsurl)
+    __select__ = is_instance('Project') & score_entity(lambda x: x.vcsurl)
     title = None # should not appears in possible views
 
     def cell_call(self, row, col):
@@ -109,7 +109,7 @@ class ExtProjectOutOfContextView(baseviews.OutOfContextView):
     """project's secondary view display project's url, which is not
     displayed in the one line / text views
     """
-    __select__ = implements('ExtProject')
+    __select__ = is_instance('ExtProject')
 
     def cell_call(self, row, col):
         entity = self.cw_rset.get_entity(row, col)
@@ -121,21 +121,22 @@ class ExtProjectOutOfContextView(baseviews.OutOfContextView):
 
 
 class ProjectTextView(baseviews.TextView):
-    __select__ = implements('Project')
+    __select__ = is_instance('Project')
 
     def cell_call(self, row, col):
         """ text_view representation of a project """
         entity = self.cw_rset.get_entity(row, col)
         self.w(entity.name)
-        if entity.state != 'active development':
-            self.w(u' [%s]' % self._cw._(entity.state))
+        state = entity.cw_adapt_to('IWorkflowable').state
+        if state != 'active development':
+            self.w(u' [%s]' % self._cw._(state))
 
 
 class ProjectOutOfContextView(tracker.ProjectOutOfContextView):
     """project's secondary view display project's url, which is not
     displayed in the one line / text views
     """
-    __select__ = implements('Project')
+    __select__ = is_instance('Project')
 
     def cell_call(self, row, col):
         entity = self.cw_rset.get_entity(row, col)
@@ -152,7 +153,7 @@ class ProjectOutOfContextView(tracker.ProjectOutOfContextView):
 
 class ProjectTestReportsAction(action.Action):
     __regid__ = 'testreports'
-    __select__ = implements('Project') & score_entity(lambda x: x.reporturl)
+    __select__ = is_instance('Project') & score_entity(lambda x: x.reporturl)
 
     title = _('test reports')
     order = 220
@@ -163,8 +164,8 @@ class ProjectTestReportsAction(action.Action):
                               vtitle=self._cw._(self.title))
 
 class ProjectAddRelatedAction(action.LinkToEntityAction):
-    __select__ = (action.LinkToEntityAction.__select__ & implements('Project')
-                  & score_entity(lambda x: x.state != 'moved'))
+    __select__ = (action.LinkToEntityAction.__select__ & is_instance('Project')
+                  & score_entity(lambda x: x.cw_adapt_to('IWorkflowable').state != 'moved'))
 
 class ProjectAddTicket(ProjectAddRelatedAction):
     __regid__ = 'addticket'
@@ -202,8 +203,8 @@ class ProjectAddScreenshot(ProjectAddRelatedAction):
     __regid__ = 'addscreenshot'
     rtype = 'screenshot'
     role = 'subject'
-    target_etype = 'Image'
-    title = _('add Project screenshot Image subject')
+    target_etype = 'File'
+    title = _('add Project screenshot File subject')
     order = 122
 
 class ProjectAddSubProject(ProjectAddRelatedAction):
@@ -222,7 +223,7 @@ class ProjectAddTestCard(testcard.ProjectAddTestCard):
 # some are missing because they are defined in tracker
 _('creating Card (Project %(linkto)s) documented_by Card')
 _('creating File (Project %(linkto)s) documented_by File')
-_('creating Image (Project %(linkto)s) screenshot File')
+_('creating File (Project %(linkto)s) screenshot File')
 
 _abaa = uicfg.actionbox_appearsin_addmenu
 for cls in ProjectAddRelatedAction.__subclasses__():
